What’s Next
===========

Congratulations on finishing the SymPy tutorial!

If you are a developer interested in using SymPy in your code, please visit the :ref:`How-to Guides <guides>` which discuss key developer tasks.

Intermediate SymPy users and developers might want to visit the :ref:`Explanation <explanation>` section for common pitfalls and advanced topics.

The :ref:`SymPy API Reference <reference>` has a detailed description of the SymPy API.
